@@ -146,6 +146,9 @@
 
 struct _GSettingsPrivate
 {
+  /* where the signals go... */
+  GMainContext *main_context;
+
   GSettingsBackend *backend;
   GSettingsSchema *schema;
   gchar *schema_name;
@@ -221,11 +224,11 @@ g_settings_real_writable_change_event (GSettings *settings,
 
 static void
 settings_backend_changed (GSettingsBackend    *backend,
+                          GObject             *target,
                           const gchar         *key,
-                          gpointer             origin_tag,
-                          gpointer             user_data)
+                          gpointer             origin_tag)
 {
-  GSettings *settings = G_SETTINGS (user_data);
+  GSettings *settings = G_SETTINGS (target);
   gboolean ignore_this;
   gint i;
 
@@ -246,11 +249,11 @@ settings_backend_changed (GSettingsBackend    *backend,
 
 static void
 settings_backend_path_changed (GSettingsBackend *backend,
+                               GObject          *target,
                                const gchar      *path,
-                               gpointer          origin_tag,
-                               gpointer          user_data)
+                               gpointer          origin_tag)
 {
-  GSettings *settings = G_SETTINGS (user_data);
+  GSettings *settings = G_SETTINGS (target);
   gboolean ignore_this;
 
   g_assert (settings->priv->backend == backend);
@@ -262,12 +265,12 @@ settings_backend_path_changed (GSettingsBackend *backend,
 
 static void
 settings_backend_keys_changed (GSettingsBackend    *backend,
+                               GObject             *target,
                                const gchar         *path,
                                const gchar * const *items,
-                               gpointer             origin_tag,
-                               gpointer             user_data)
+                               gpointer             origin_tag)
 {
-  GSettings *settings = G_SETTINGS (user_data);
+  GSettings *settings = G_SETTINGS (target);
   gboolean ignore_this;
   gint i;
 
@@ -306,10 +309,10 @@ settings_backend_keys_changed (GSettingsBackend    *backend,
 
 static void
 settings_backend_writable_changed (GSettingsBackend *backend,
-                                   const gchar      *key,
-                                   gpointer          user_data)
+                                   GObject          *target,
+                                   const gchar      *key)
 {
-  GSettings *settings = G_SETTINGS (user_data);
+  GSettings *settings = G_SETTINGS (target);
   gboolean ignore_this;
   gint i;
 
@@ -325,10 +328,10 @@ settings_backend_writable_changed (GSettingsBackend *backend,
 
 static void
 settings_backend_path_writable_changed (GSettingsBackend *backend,
-                                        const gchar      *path,
-                                        gpointer          user_data)
+                                        GObject          *target,
+                                        const gchar      *path)
 {
-  GSettings *settings = G_SETTINGS (user_data);
+  GSettings *settings = G_SETTINGS (target);
   gboolean ignore_this;
 
   g_assert (settings->priv->backend == backend);
@@ -362,13 +365,13 @@ g_settings_constructed (GObject *object)
     }
 
   settings->priv->backend = g_settings_backend_get_with_context (settings->priv->context);
-  g_settings_backend_watch (settings->priv->backend,
+  g_settings_backend_watch (settings->priv->backend, G_OBJECT (settings),
+                            settings->priv->main_context,
                             settings_backend_changed,
                             settings_backend_path_changed,
                             settings_backend_keys_changed,
                             settings_backend_writable_changed,
-                            settings_backend_path_writable_changed,
-                            settings);
+                            settings_backend_path_writable_changed);
   g_settings_backend_subscribe (settings->priv->backend,
                                 settings->priv->path);
 }
@@ -379,6 +382,13 @@ g_settings_init (GSettings *settings)
   settings->priv = G_TYPE_INSTANCE_GET_PRIVATE (settings,
                                                 G_TYPE_SETTINGS,
                                                 GSettingsPrivate);
+
+  settings->priv->main_context = g_main_context_get_thread_default ();
+
+  if (settings->priv->main_context == NULL)
+    settings->priv->main_context = g_main_context_default ();
+
+  g_main_context_ref (settings->priv->main_context);
 }
 
 /**
@@ -400,18 +410,20 @@ g_settings_delay (GSettings *settings)
     return;
 
   settings->priv->delayed =
-    g_delayed_settings_backend_new (settings->priv->backend, settings);
-  g_settings_backend_unwatch (settings->priv->backend, settings);
+    g_delayed_settings_backend_new (settings->priv->backend,
+                                    settings,
+                                    settings->priv->main_context);
+  g_settings_backend_unwatch (settings->priv->backend, G_OBJECT (settings));
   g_object_unref (settings->priv->backend);
 
   settings->priv->backend = G_SETTINGS_BACKEND (settings->priv->delayed);
-  g_settings_backend_watch (settings->priv->backend,
+  g_settings_backend_watch (settings->priv->backend, G_OBJECT (settings),
+                            settings->priv->main_context,
                             settings_backend_changed,
                             settings_backend_path_changed,
                             settings_backend_keys_changed,
                             settings_backend_writable_changed,
-                            settings_backend_path_writable_changed,
-                            settings);
+                            settings_backend_path_writable_changed);
 }
 
 /**
@@ -534,9 +546,9 @@ g_settings_finalize (GObject *object)
 {
   GSettings *settings = G_SETTINGS (object);
 
-  g_settings_backend_unwatch (settings->priv->backend, settings);
   g_settings_backend_unsubscribe (settings->priv->backend,
                                   settings->priv->path);
+  g_main_context_unref (settings->priv->main_context);
   g_object_unref (settings->priv->backend);
   g_object_unref (settings->priv->schema);
   g_free (settings->priv->schema_name);
@@ -782,16 +794,13 @@ g_settings_get_value (GSettings   *settings,
       const gchar *translated;
       GError *error = NULL;
       const gchar *domain;
-      gint lc_category;
 
       domain = g_settings_schema_get_gettext_domain (settings->priv->schema);
 
       if (lc_char == 't')
-        lc_category = LC_TIME;
+        translated = g_dcgettext (domain, unparsed, LC_TIME);
       else
-        lc_category = LC_MESSAGES;
-
-      translated = dcgettext (domain, unparsed, lc_category);
+        translated = g_dgettext (domain, unparsed);
 
       if (translated != unparsed)
         /* it was translated, so we need to re-parse it */
@@ -1016,6 +1025,11 @@ g_settings_get_child (GSettings   *settings,
  *
  * Creates a new #GSettings object with a given schema.
  *
+ * Signals on the newly created #GSettings object will be dispatched
+ * via the thread-default #GMainContext in effect at the time of the
+ * call to g_settings_new().  The new #GSettings will hold a reference
+ * on the context.  See g_main_context_push_thread_default().
+ *
  * Since: 2.26
  */
 GSettings *
@@ -1449,7 +1463,6 @@ g_settings_writable_binding_free (gpointer data)
 
   g_signal_handler_disconnect (binding->settings, binding->handler_id);
   g_object_unref (binding->settings);
-  g_free (binding->key);
   g_slice_free (GSettingsWritableBinding, binding);
 }
 
@@ -1531,7 +1544,7 @@ g_settings_bind_writable (GSettings   *settings,
   binding = g_slice_new (GSettingsWritableBinding);
   binding->settings = g_object_ref (settings);
   binding->object = object;
-  binding->key = g_strdup (key);
+  binding->key = g_intern_string (key);
   binding->property = g_intern_string (property);
   binding->inverted = inverted;
 
@@ -1791,7 +1804,6 @@ g_settings_set_boolean (GSettings  *settings,
  * g_settings_get_strv:
  * @settings: a #GSettings object
  * @key: the key to get the value for
- * @length: return location for the length of the result, or %NULL
  * @returns: a newly-allocated, %NULL-terminated array of strings
  *
  * Gets the value that is stored at @key in @settings.
@@ -1805,14 +1817,13 @@ g_settings_set_boolean (GSettings  *settings,
  */
 gchar **
 g_settings_get_strv (GSettings   *settings,
-                     const gchar *key,
-                     gsize       *length)
+                     const gchar *key)
 {
   GVariant *value;
   gchar **result;
 
   value = g_settings_get_value (settings, key);
-  result = g_variant_dup_strv (value, length);
+  result = g_variant_dup_strv (value, NULL);
   g_variant_unref (value);
 
   return result;
@@ -1822,14 +1833,14 @@ g_settings_get_strv (GSettings   *settings,
  * g_settings_set_strv:
  * @settings: a #GSettings object
  * @key: the name of the key to set
- * @value: the value to set it to
- * @length: the length of the @value array, or -1
+ * @value: (allow-none): the value to set it to, or %NULL
  * @returns: %TRUE if setting the key succeeded,
  *     %FALSE if the key was not writable
  *
  * Sets @key in @settings to @value.
  *
- * A convenience variant of g_settings_set() for string arrays.
+ * A convenience variant of g_settings_set() for string arrays.  If
+ * @value is %NULL, then @key is set to be the empty array.
  *
  * It is a programmer error to pass a @key that isn't valid for
  * @settings or is not of type 'string array'.
@@ -1839,10 +1850,16 @@ g_settings_get_strv (GSettings   *settings,
 gboolean
 g_settings_set_strv (GSettings           *settings,
                      const gchar         *key,
-                     const gchar * const *value,
-                     gssize               length)
+                     const gchar * const *value)
 {
-  return g_settings_set_value (settings, key, g_variant_new_strv (value, length));
+  GVariant *array;
+
+  if (value)
+    array = g_variant_new_strv (value, -1);
+  else
+    array = g_variant_new_strv (NULL, 0);
+
+  return g_settings_set_value (settings, key, array);
 }
 
 #define __G_SETTINGS_C__
