@@ -50,8 +50,8 @@
  * UNIX file descriptor, including asynchronous operations. The file
  * descriptor must be selectable, so it doesn't work with opened files.
  *
- * Note that <filename>&lt;gio/gunixinputstream.h&gt;</filename> belongs 
- * to the UNIX-specific GIO interfaces, thus you have to use the 
+ * Note that <filename>&lt;gio/gunixinputstream.h&gt;</filename> belongs
+ * to the UNIX-specific GIO interfaces, thus you have to use the
  * <filename>gio-unix-2.0.pc</filename> pkg-config file when using it.
  */
 
@@ -116,10 +116,6 @@ static gboolean g_unix_input_stream_close_finish (GInputStream         *stream,
 static void
 g_unix_input_stream_finalize (GObject *object)
 {
-  GUnixInputStream *stream;
-  
-  stream = G_UNIX_INPUT_STREAM (object);
-
   G_OBJECT_CLASS (g_unix_input_stream_parent_class)->finalize (object);
 }
 
@@ -158,8 +154,8 @@ g_unix_input_stream_class_init (GUnixInputStreamClass *klass)
   g_object_class_install_property (gobject_class,
 				   PROP_FD,
 				   g_param_spec_int ("fd",
-						     _("File descriptor"),
-						     _("The file descriptor to read from"),
+						     P_("File descriptor"),
+						     P_("The file descriptor to read from"),
 						     G_MININT, G_MAXINT, -1,
 						     G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
@@ -173,8 +169,8 @@ g_unix_input_stream_class_init (GUnixInputStreamClass *klass)
   g_object_class_install_property (gobject_class,
 				   PROP_CLOSE_FD,
 				   g_param_spec_boolean ("close-fd",
-							 _("Close file descriptor"),
-							 _("Whether to close the file descriptor when the stream is closed"),
+							 P_("Close file descriptor"),
+							 P_("Whether to close the file descriptor when the stream is closed"),
 							 TRUE,
 							 G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 }
@@ -340,15 +336,15 @@ g_unix_input_stream_read (GInputStream  *stream,
 
   unix_stream = G_UNIX_INPUT_STREAM (stream);
 
-  if (cancellable)
+  if (g_cancellable_make_pollfd (cancellable, &poll_fds[1]))
     {
       poll_fds[0].fd = unix_stream->priv->fd;
       poll_fds[0].events = G_IO_IN;
-      g_cancellable_make_pollfd (cancellable, &poll_fds[1]);
       do
 	poll_ret = g_poll (poll_fds, 2, -1);
       while (poll_ret == -1 && errno == EINTR);
-      
+      g_cancellable_release_fd (cancellable);
+
       if (poll_ret == -1)
 	{
           int errsv = errno;
@@ -507,7 +503,7 @@ g_unix_input_stream_read_async (GInputStream        *stream,
 			     cancellable);
   
   g_source_set_callback (source, (GSourceFunc)read_async_cb, data, g_free);
-  g_source_attach (source, NULL);
+  g_source_attach (source, g_main_context_get_thread_default ());
  
   g_source_unref (source);
 }
@@ -635,7 +631,7 @@ g_unix_input_stream_close_async (GInputStream        *stream,
   
   idle = g_idle_source_new ();
   g_source_set_callback (idle, (GSourceFunc)close_async_cb, data, close_async_data_free);
-  g_source_attach (idle, NULL);
+  g_source_attach (idle, g_main_context_get_thread_default ());
   g_source_unref (idle);
 }
 
