@@ -498,7 +498,6 @@ gboolean
 g_match_info_next (GMatchInfo  *match_info,
 		   GError     **error)
 {
-  gint opts;
   gint prev_match_start;
   gint prev_match_end;
 
@@ -506,8 +505,6 @@ g_match_info_next (GMatchInfo  *match_info,
   g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
   g_return_val_if_fail (match_info->pos >= 0, FALSE);
 
-  opts = match_info->regex->match_opts | match_info->match_opts;
- 
   prev_match_start = match_info->offsets[0];
   prev_match_end = match_info->offsets[1];
 
@@ -516,8 +513,7 @@ g_match_info_next (GMatchInfo  *match_info,
 				   match_info->string,
 				   match_info->string_len,
 				   match_info->pos,
-				   match_info->regex->match_opts |
-				   match_info->match_opts,
+				   match_info->regex->match_opts | match_info->match_opts,
 				   match_info->offsets,
                                    match_info->n_offsets);
   if (IS_PCRE_ERROR (match_info->matches))
@@ -794,7 +790,7 @@ g_match_info_fetch (const GMatchInfo *match_info,
  * @start_pos: pointer to location where to store the start position
  * @end_pos: pointer to location where to store the end position
  *
- * Retrieves the position of the @match_num<!-- -->'th capturing 
+ * Retrieves the position in bytes of the @match_num<!-- -->'th capturing 
  * parentheses. 0 is the full text of the match, 1 is the first 
  * paren set, 2 the second, and so on.
  *
@@ -917,7 +913,7 @@ g_match_info_fetch_named (const GMatchInfo *match_info,
  * @start_pos: pointer to location where to store the start position
  * @end_pos: pointer to location where to store the end position
  *
- * Retrieves the position of the capturing parentheses named @name.
+ * Retrieves the position in bytes of the capturing parentheses named @name.
  *
  * If @name is a valid sub pattern name but it didn't match anything 
  * (e.g. sub pattern "X", matching "b" against "(?P&lt;X&gt;a)?b") 
@@ -1199,6 +1195,8 @@ g_regex_new (const gchar         *pattern,
                                            regex->pattern,
                                            errmsg);
           g_propagate_error (error, tmp_error);
+
+          g_regex_unref (regex);
           return NULL;
 	}
     }
@@ -1269,6 +1267,42 @@ g_regex_get_capture_count (const GRegex *regex)
   return value;
 }
 
+/**
+ * g_regex_get_compile_flags:
+ * @regex: a #GRegex
+ *
+ * Returns the compile options that @regex was created with.
+ *
+ * Returns: flags from #GRegexCompileFlags
+ *
+ * Since: 2.26
+ */
+GRegexCompileFlags
+g_regex_get_compile_flags (GRegex *regex)
+{
+  g_return_val_if_fail (regex != NULL, 0);
+
+  return regex->compile_opts;
+}
+
+/**
+ * g_regex_get_match_flags:
+ * @regex: a #GRegex
+ *
+ * Returns the match options that @regex was created with.
+ *
+ * Returns: flags from #GRegexMatchFlags
+ *
+ * Since: 2.26
+ */
+GRegexMatchFlags
+g_regex_get_match_flags (GRegex *regex)
+{
+  g_return_val_if_fail (regex != NULL, 0);
+
+  return regex->match_opts;
+}
+
 /**
  * g_regex_match_simple:
  * @pattern: the regular expression
@@ -1351,6 +1385,10 @@ g_regex_match_simple (const gchar        *pattern,
  * }
  * ]|
  *
+ * @string is not copied and is used in #GMatchInfo internally. If 
+ * you use any #GMatchInfo method (except g_match_info_free()) after 
+ * freeing or modifying @string then the behaviour is undefined.
+ *
  * Returns: %TRUE is the string matched, %FALSE otherwise
  *
  * Since: 2.14
@@ -1478,6 +1516,10 @@ g_regex_match_full (const GRegex      *regex,
  * i.e. you must free it regardless if regular expression actually 
  * matched.
  *
+ * @string is not copied and is used in #GMatchInfo internally. If 
+ * you use any #GMatchInfo method (except g_match_info_free()) after 
+ * freeing or modifying @string then the behaviour is undefined.
+ * 
  * Returns: %TRUE is the string matched, %FALSE otherwise
  *
  * Since: 2.14
@@ -1536,6 +1578,10 @@ g_regex_match_all (const GRegex      *regex,
  * i.e. you must free it regardless if regular expression actually 
  * matched.
  *
+ * @string is not copied and is used in #GMatchInfo internally. If 
+ * you use any #GMatchInfo method (except g_match_info_free()) after 
+ * freeing or modifying @string then the behaviour is undefined.
+ *
  * Returns: %TRUE is the string matched, %FALSE otherwise
  *
  * Since: 2.14
@@ -2367,7 +2413,7 @@ interpolation_list_needs_match (GList *list)
  * @match_options: options for the match
  * @error: location to store the error occuring, or %NULL to ignore errors
  *
- * Replaces all occurances of the pattern in @regex with the
+ * Replaces all occurrences of the pattern in @regex with the
  * replacement text. Backreferences of the form '\number' or 
  * '\g&lt;number&gt;' in the replacement text are interpolated by the 
  * number-th captured subexpression of the match, '\g&lt;name&gt;' refers 
@@ -2479,7 +2525,7 @@ literal_replacement (const GMatchInfo *match_info,
  * @match_options: options for the match
  * @error: location to store the error occuring, or %NULL to ignore errors
  *
- * Replaces all occurances of the pattern in @regex with the
+ * Replaces all occurrences of the pattern in @regex with the
  * replacement text. @replacement is replaced literally, to
  * include backreferences use g_regex_replace().
  *
@@ -2523,8 +2569,8 @@ g_regex_replace_literal (const GRegex      *regex,
  * @user_data: user data to pass to the function
  * @error: location to store the error occuring, or %NULL to ignore errors
  *
- * Replaces occurances of the pattern in regex with the output of 
- * @eval for that occurance.
+ * Replaces occurrences of the pattern in regex with the output of 
+ * @eval for that occurrence.
  *
  * Setting @start_position differs from just passing over a shortened 
  * string and setting #G_REGEX_MATCH_NOTBOL in the case of a pattern 
