@@ -167,11 +167,12 @@ token_stream_prepare (TokenStream *stream)
       break;
 
     case '@': case '%':
-      /* stop at the first space, comma or unmatched bracket.
-       * deals nicely with cases like (%i, %i).
+      /* stop at the first space, comma, colon or unmatched bracket.
+       * deals nicely with cases like (%i, %i) or {%i: %i}.
        */
       for (end = stream->stream + 1;
-           end != stream->end && *end != ',' && !g_ascii_isspace (*end);
+           end != stream->end && *end != ',' &&
+           *end != ':' && !g_ascii_isspace (*end);
            end++)
 
         if (*end == '(' || *end == '{')
@@ -1408,6 +1409,42 @@ string_free (AST *ast)
   g_slice_free (String, string);
 }
 
+static gboolean
+unicode_unescape (const gchar  *src,
+                  gint         *src_ofs,
+                  gchar        *dest,
+                  gint         *dest_ofs,
+                  gint          length,
+                  SourceRef    *ref,
+                  GError      **error)
+{
+  gchar buffer[9];
+  guint64 value;
+  gchar *end;
+
+  (*src_ofs)++;
+
+  g_assert (length < sizeof (buffer));
+  strncpy (buffer, src + *src_ofs, length);
+  buffer[length] = '\0';
+
+  value = g_ascii_strtoull (buffer, &end, 0x10);
+
+  if (value == 0 || end != buffer + length)
+    {
+      parser_set_error (error, ref, NULL,
+                        "invalid %d-character unicode escape", length);
+      return FALSE;
+    }
+
+  g_assert (value <= G_MAXUINT32);
+
+  *dest_ofs += g_unichar_to_utf8 (value, dest + *dest_ofs);
+  *src_ofs += length;
+
+  return TRUE;
+}
+
 static AST *
 string_parse (TokenStream  *stream,
               va_list      *app,
@@ -1454,27 +1491,29 @@ string_parse (TokenStream  *stream,
             g_free (token);
             return NULL;
 
-          case '0': case '1': case '2': case '3':
-          case '4': case '5': case '6': case '7':
-            {
-              /* up to 3 characters */
-              guchar val = token[i++] - '0';
-
-              if ('0' <= token[i] && token[i] < '8')
-                val = (val << 3) | (token[i++] - '0');
-
-              if ('0' <= token[i] && token[i] < '8')
-                val = (val << 3) | (token[i++] - '0');
-
-              str[j++] = val;
-            }
+          case 'u':
+            if (!unicode_unescape (token, &i, str, &j, 4, &ref, error))
+              {
+                g_free (token);
+                return NULL;
+              }
             continue;
 
+          case 'U':
+            if (!unicode_unescape (token, &i, str, &j, 8, &ref, error))
+              {
+                g_free (token);
+                return NULL;
+              }
+            continue;
+
+          case 'a': str[j++] = '\a'; i++; continue;
           case 'b': str[j++] = '\b'; i++; continue;
           case 'f': str[j++] = '\f'; i++; continue;
           case 'n': str[j++] = '\n'; i++; continue;
           case 'r': str[j++] = '\r'; i++; continue;
           case 't': str[j++] = '\t'; i++; continue;
+          case 'v': str[j++] = '\v'; i++; continue;
           case '\n': i++; continue;
           }
 
@@ -2057,7 +2096,7 @@ g_variant_parse (const GVariantType  *type,
                  const gchar        **endptr,
                  GError             **error)
 {
-  TokenStream stream = {  };
+  TokenStream stream = { 0, };
   GVariant *result = NULL;
   AST *ast;
 
@@ -2135,7 +2174,7 @@ GVariant *
 g_variant_new_parsed_va (const gchar *format,
                          va_list     *app)
 {
-  TokenStream stream = {  };
+  TokenStream stream = { 0, };
   GVariant *result = NULL;
   GError *error = NULL;
   AST *ast;
@@ -2209,5 +2248,49 @@ g_variant_new_parsed (const gchar *format,
   return result;
 }
 
+/**
+ * g_variant_builder_add_parsed:
+ * @builder: a #GVariantBuilder
+ * @format: a text format #GVariant
+ * @...: arguments as per @format
+ *
+ * Adds to a #GVariantBuilder.
+ *
+ * This call is a convenience wrapper that is exactly equivalent to
+ * calling g_variant_new_parsed() followed by
+ * g_variant_builder_add_value().
+ *
+ * This function might be used as follows:
+ *
+ * <programlisting>
+ * GVariant *
+ * make_pointless_dictionary (void)
+ * {
+ *   GVariantBuilder *builder;
+ *   int i;
+ *
+ *   builder = g_variant_builder_new (G_VARIANT_TYPE_ARRAY);
+ *   g_variant_builder_add_parsed (builder, "{'width', <%i>}", 600);
+ *   g_variant_builder_add_parsed (builder, "{'title', <%s>}", "foo");
+ *   g_variant_builder_add_parsed (builder, "{'transparency', <0.5>}");
+ *   return g_variant_builder_end (builder);
+ * }
+ * </programlisting>
+ *
+ * Since: 2.26
+ **/
+void
+g_variant_builder_add_parsed (GVariantBuilder *builder,
+                              const gchar     *format,
+                              ...)
+{
+  va_list ap;
+
+  va_start (ap, format);
+  g_variant_builder_add_value (builder, g_variant_new_parsed_va (format, ap));
+  va_end (ap);
+}
+
+
 #define __G_VARIANT_PARSER_C__
 #include "galiasdef.c"
